# Geographically Weighted Canonical Correlation Analysis (GWCCA)

### This module provides functionality to calibrate GWCCA for local spatial associations between two sets of variables


### Features

This article critically assesses the utility of the classical statistical technique of Canonical Correlation Analysis (CCA) to study spatial associations and proposes a new approach to enhance it. Unlike bivariate correlation analysis, which focuses on the relationship between two individual variables, CCA investigates associations between two sets of variables by finding pairs of linear combinations that are maximally correlated. CCA has great potential for uncovering complex multivariate relationships that vary across geographic space. We propose Geographically Weighted Canonical Correlation Analysis (GWCCA) as a new technique to explore local spatial associations between two sets of variables. GWCCA localizes standard CCA by weighting each observation according to its spatial distance from a target location, thereby estimating location-specific canonical correlations. GWCCA’s effectiveness in recovering spatial structure and capturing spatial effects has been evaluated with synthetic data. A case study of US county-level health outcomes and social determinants of health is conducted to demonstrate GWCCA’s capabilities empirically. It is concluded that GWCCA has the potential for a wide range of applications in spatial data–intensive fields such as urban planning, environmental science, public health, and transportation, where understanding local spatial associations in multivariate dimensions is crucial.

### Citation:

To cite this paper: Zhenzhi Jiao, Angela Yao, Ran Tao and Jean-Claude Thill (2026). Geographically Weighted Canonical Correlation Analysis: Local Spatial Associations Between Two Sets of Variables. Annals of the American Association of Geographers. (forthcoming)
